==> lxqt-l10n-0.11.2.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-clock/clock_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">LXQt时钟设置</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>时间</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>显示秒(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>12小时样式(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">字体(&amp;F)</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">字体</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">显示日期(&amp;D)</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">日期格式(&amp;A)</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">字体(&amp;T)</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">在新行显示日期(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">使用主题字体(&amp;U)</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">时间字体</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">日期字体</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">超亮</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">亮</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">超黑</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">黑</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">黑体</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">半粗体</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">斜体</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-clock/clock_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClock</name>
    <message>
        <location filename="../../../lxqtclock.cpp" line="57"/>
        <source>Date&amp;Time (clock) plugin is deprecated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="58"/>
        <source>The &lt;strong&gt;clock&lt;/strong&gt; plugin is deprecated and will be removed in future version of LXQt. Consider replacing it with &lt;strong&gt;worldclock&lt;/strong&gt;.&lt;br/&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="60"/>
        <source>don&apos;t show this again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">LXQt时钟设置</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>时间</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>显示秒(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>12小时样式(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">字体(&amp;F)</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">字体</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">显示日期(&amp;D)</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">日期格式(&amp;A)</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">字体(&amp;T)</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">在新行显示日期(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">使用主题字体(&amp;U)</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">时间字体</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">日期字体</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">超亮</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">亮</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">超黑</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">黑</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">黑体</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">半粗体</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">斜体</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
